pecos.qeclib.steane.gates\_sq.face\_rots
========================================

.. automodule:: pecos.qeclib.steane.gates_sq.face_rots











   .. rubric:: Classes

   .. autosummary::

      F
      Fdg
